==> haskell-code-page-0.2-8-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-code-page.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 code-page
version:              0.2
visibility:           public
id:                   code-page-0.2-Hd303LwEsRgBXOr5sG6RzS
key:                  code-page-0.2-Hd303LwEsRgBXOr5sG6RzS
license:              BSD-3-Clause
copyright:            (C) 2016-2017 Ryan Scott
maintainer:           Ryan Scott <ryan.gl.scott@gmail.com>
author:               Ryan Scott
stability:            Provisional
homepage:             https://github.com/RyanGlScott/code-page
synopsis:             Windows code page library for Haskell
description:
    This library provides two modules:

    * "System.IO.CodePage": a cross-platform module that exports
    functions which adjust code pages on Windows, and do nothing
    on other operating systems.

    * "System.Win32.CodePage": On Windows, this exports functions
    for getting, setting, and analyzing code pages. On other
    operating systems, this module exports nothing.

category:             System
abi:                  ad2b1552759aed0d3cdf9b6fc408ff57
exposed:              True
exposed-modules:
    System.IO.CodePage System.IO.CodePage.Internal
    System.Win32.CodePage

import-dirs:          /usr/lib/ghc-8.10.1/site-local/code-page-0.2
library-dirs:         /usr/lib/ghc-8.10.1/site-local/code-page-0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/code-page-0.2
hs-libraries:         HScode-page-0.2-Hd303LwEsRgBXOr5sG6RzS
depends:              base-4.14.0.0
haddock-interfaces:   /usr/share/doc/haskell-code-page/html/code-page.haddock
haddock-html:         /usr/share/doc/haskell-code-page/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-code-page-0.2-10-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-code-page.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 code-page
version:              0.2
visibility:           public
id:                   code-page-0.2-1lNAShZKBs0E8I4pr7cPwp
key:                  code-page-0.2-1lNAShZKBs0E8I4pr7cPwp
license:              BSD-3-Clause
copyright:            (C) 2016-2017 Ryan Scott
maintainer:           Ryan Scott <ryan.gl.scott@gmail.com>
author:               Ryan Scott
stability:            Provisional
homepage:             https://github.com/RyanGlScott/code-page
synopsis:             Windows code page library for Haskell
description:
    This library provides two modules:

    * "System.IO.CodePage": a cross-platform module that exports
    functions which adjust code pages on Windows, and do nothing
    on other operating systems.

    * "System.Win32.CodePage": On Windows, this exports functions
    for getting, setting, and analyzing code pages. On other
    operating systems, this module exports nothing.

category:             System
abi:                  1eba692ff432bddb290ceb6f185351c1
exposed:              True
exposed-modules:
    System.IO.CodePage System.IO.CodePage.Internal
    System.Win32.CodePage

import-dirs:          /usr/lib/ghc-8.10.2/site-local/code-page-0.2
library-dirs:         /usr/lib/ghc-8.10.2/site-local/code-page-0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/code-page-0.2
hs-libraries:         HScode-page-0.2-1lNAShZKBs0E8I4pr7cPwp
depends:              base-4.14.1.0
haddock-interfaces:   /usr/share/doc/haskell-code-page/html/code-page.haddock
haddock-html:         /usr/share/doc/haskell-code-page/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
